@@ -84,7 +84,7 @@ class ContainerLauncher:
         ec2_sg_id = container_input.get('ec2_sg_id')
 
         try:
-            self.__options['name_suffix'] = entry_id
+            self.__options['name_suffix'] = container_input.get('name_suffix', str(uuid.uuid4()).replace('-', ''))
 
             if self.get_container_status(entry_id)['status'] != RunStatus.UNKNOWN.name:
                 self.logger.warning(f'The monitoring record with {entry_id} ID already exists')
@@ -177,7 +177,7 @@ class ContainerLauncher:
 
             logs = {
                 'log_group': '/aws/batch/job',
-                'log_stream': f'{self.__ECS_TASK_LOG_STREAM_PREFIX}-{entry_id}'
+                'log_stream': f"{self.__ECS_TASK_LOG_STREAM_PREFIX}-{self.__options['name_suffix']}"
             }
 
             self.logger.info(f'ECS task logs: {json.dumps(logs)}')
@@ -187,7 +187,8 @@ class ContainerLauncher:
 
             return {
                 'resources': self.__resources,
-                'entry_id': entry_id
+                'entry_id': entry_id,
+                'logs': logs
             }
 
         except Exception as e:
@@ -201,23 +202,16 @@ class ContainerLauncher:
     def get_container_status(self, entry_id):
         entry = self.__dynamodb.get_entry(entry_id)
 
-        logs = {
-            'log_group': '/aws/batch/job',
-            'log_stream': f'{self.__ECS_TASK_LOG_STREAM_PREFIX}-{entry_id}'
-        }
-
         if entry is None:
             return {
-                'status': RunStatus.UNKNOWN.name,
-                'logs': logs
+                'status': RunStatus.UNKNOWN.name
             }
 
         run_status = entry['status']
 
         if run_status != RunStatus.IN_PROGRESS.name:
             return {
-                'status': run_status,
-                'logs': logs
+                'status': run_status
             }
 
         response = self.clients['ecs'].describe_tasks(
@@ -234,21 +228,18 @@ class ContainerLauncher:
             if exit_code == 0:
                 self.__dynamodb.update_status(entry_id, RunStatus.COMPLETED.name)
                 return {
-                    'status': RunStatus.COMPLETED.name,
-                    'logs': logs
+                    'status': RunStatus.COMPLETED.name
                 }
             error_message = str(ecs_task["containers"][0])
             self.logger.warning(f'The ECS task failed: {error_message}')
             self.__dynamodb.update_status(entry_id, RunStatus.FAILED.name)
             return {
                 'status': RunStatus.FAILED.name,
-                'logs': logs,
                 'error': error_message
             }
 
         return {
-            'status': RunStatus.IN_PROGRESS.name,
-            'logs': logs
+            'status': RunStatus.IN_PROGRESS.name
         }
 
     def destroy(self, entry_id):
